#!/usr/bin/env python


def format_output(output, omit):
    if output == "":
        return omit
    return output


class FilterModule(object):
    ''' A filter to fix output format '''
    def filters(self):
        return {
            'omit_filter': format_output
        }



#!/usr/bin/env python


def fetch_attr(output_dict, attr, default):
    return output_dict.get(attr, default)


class FilterModule(object):
    ''' A filter to fetch ann attr from dict '''
    def filters(self):
        return {
            'fetch_attr': fetch_attr
        }
